this paragraph is not `** <#id1>`__\ clean.

.. class:: system-message

.. _id1:

============================
WARNING/2 (<string>, line 1)
============================

Inline strong start-string without end-string.
